# Filter

Filter commands are used to create real-time filters of output request data.

## Create filters

### In Mdb

```{eval-rst}
.. autoclass:: abaqus.Filter.FilterModel.FilterModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### In Odb

```{eval-rst}
.. autoclass:: abaqus.Filter.FilterOdb.FilterOdb
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Classes

### Filter

```{eval-rst}
.. autoclass:: abaqus.Filter.Filter.Filter
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ButterworthFilter

```{eval-rst}
.. autoclass:: abaqus.Filter.ButterworthFilter.ButterworthFilter
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Chebyshev1Filter

```{eval-rst}
.. autoclass:: abaqus.Filter.Chebyshev1Filter.Chebyshev1Filter
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Chebyshev2Filter

```{eval-rst}
.. autoclass:: abaqus.Filter.Chebyshev2Filter.Chebyshev2Filter
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OperatorFilter

```{eval-rst}
.. autoclass:: abaqus.Filter.OperatorFilter.OperatorFilter
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
